Package: yarn
Title: YARN: Robust Multi-Condition RNA-Seq Preprocessing and
        Normalization
Version: 1.37.0
Authors@R: c(person(given = "Joseph N","Paulson",email =
        "paulson.joseph@gene.com",role = c("aut", "cre")),
        person("Cho-Yi","Chen",role="aut"),
        person("Camila","Lopes-Ramos",role="aut"),
        person("Marieke","Kuijjer",role="aut"),
        person("John","Platig",role="aut"),
        person("Abhijeet","Sonawane",role="aut"),
        person("Maud","Fagny",role="aut"),
        person("Kimberly","Glass",role="aut"),
        person("John","Quackenbush",email =
        "johnq@jimmy.harvard.edu",role="aut"))
Description: Expedite large RNA-Seq analyses using a combination of
        previously developed tools. YARN is meant to make it easier for
        the user in performing basic mis-annotation quality control,
        filtering, and condition-aware normalization. YARN leverages
        many Bioconductor tools and statistical techniques to account
        for the large heterogeneity and sparsity found in very large
        RNA-seq experiments.
Depends: Biobase
License: Artistic-2.0
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.1.1
Suggests: knitr, rmarkdown, testthat (>= 0.8)
Imports: biomaRt, downloader, edgeR, gplots, graphics, limma,
        matrixStats, preprocessCore, readr, RColorBrewer, stats,
        quantro
VignetteBuilder: knitr
biocViews: Software, QualityControl, GeneExpression, Sequencing,
        Preprocessing, Normalization, Annotation, Visualization,
        Clustering
git_url: https://git.bioconductor.org/packages/yarn
git_branch: devel
git_last_commit: 1ca2322
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-11-04
NeedsCompilation: no
Packaged: 2025-11-05 01:42:46 UTC; biocbuild
Author: Joseph N Paulson [aut, cre],
  Cho-Yi Chen [aut],
  Camila Lopes-Ramos [aut],
  Marieke Kuijjer [aut],
  John Platig [aut],
  Abhijeet Sonawane [aut],
  Maud Fagny [aut],
  Kimberly Glass [aut],
  John Quackenbush [aut]
Maintainer: Joseph N Paulson <paulson.joseph@gene.com>
